Name:           libexplain
Version:        1.0.D001
Release:        2%{?dist}
Summary:        Library functions to explain system call errors
URL:            http://libexplain.sourceforge.net

Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz

License:        LGPLv3+
Group:          System Environment/Libraries

BuildRequires:  bison libcap-devel libtool groff gettext

%description
The libexplain project provides a library which may be used to explain
Unix and Linux system call errors. This will make your application's
error messages much more informative to your users.  The library is
not quite a drop-in replacement for strerror, but it comes close. Each
system call has a dedicated libexplain function.

The coverage for system calls is being improved all the time. Coverage
includes 159 system calls and 444 ioctl requests.

%package -n explain
Summary:        Explains system call error reports
License:        GPLv3+
Group:          Development/Tools

%description -n explain
The explain command is used to decode an error return read from an
strace(1) listing, or similar.  Because this is being deciphered in a
different process than the original, the results will be less accurate
than if the program itself were to use libexplain(3).

%package devel
Summary:        Development files for libexplain
License:        LGPLv3+ and GPLv3+
Group:          Development/Libraries
Requires:       libexplain = %{version}-%{release}
Requires:       pkgconfig

%description devel
Development files for the libexplain library.

%prep
%setup -q

# In some releases of libexplain, some tests fail in a way that does
# not indicate a fault in libexplain. Skip those tests.  Note that
# Makefile.in is automatically generated upstream, and if we use a
# patch against it, the patch will usually break with each new
# upstream release.  Instead we use sed to patch it.

# t0524a fails for mock/koji builds, but succeeds for normal builds.
# This may be due to the use of a chroot environment.  I reported this
# problem on the libexplain mailing list on 22-JAN-2012 and 11-MAR-2012,
# but as of 8-JUL-2012 there has been no response.
%define skiptests t0524a

for t in %{skiptests}
do
  sed -i "s/\([ \t]\)$t\([ \t]\)/\1/g" Makefile.in
done

%build
./configure --disable-static \
            --prefix=%{_prefix} \
            --libdir=%{_libdir}
            
make CFLAGS="%{optflags}" \
     %{?_smp_mflags}

%check
make check

%install
# The install target is not smp-safe, so don't use smp_mflags.
make DESTDIR=%{buildroot} \
     install
# The shared library has to be executable!
chmod 755 %{buildroot}%{_libdir}/%{name}.so.*.*.*
# Get rid of the static library and libtool archives
rm %{buildroot}%{_libdir}/%{name}.{a,la}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%{_libdir}/%{name}.so.*
%doc README LICENSE

%files -n explain
%{_bindir}/explain
%{_mandir}/man1/*.1.*

%files devel
%{_mandir}/man3/*.3.*
%{_includedir}/%{name}/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.D001-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sun Jul 08 2012 Eric Smith <eric@brouhaha.com> - 1.0.D001-1
- Updated to latest upstream.

* Sun Jan 22 2012 Eric Smith <eric@brouhaha.com> - 0.52.D002-1
- Updated to latest upstream.

* Sun Jan 22 2012 Eric Smith <eric@brouhaha.com> - 0.50.D001-1
- Updated to latest upstream.
- Updated list of tests to skip.

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.47.D001-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sat Oct 08 2011 Eric Smith <eric@brouhaha.com> - 0.47.D001-1
- Updated to latest upstream.
- Changed Patch0 to use of sed to better deal with new upstream releases.
- Removed BuildRoot, clean, defattr, etc.

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.40.D001-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Jan 02 2011 Eric Smith <eric@brouhaha.com> - 0.40.D001-1
- updated to latest upstream
- updated based on package review comments

* Tue Sep 07 2010 Eric Smith <eric@brouhaha.com> - 0.38.D001-1
- updated to latest upstream

* Mon May 10 2010 Eric Smith <eric@brouhaha.com> - 0.31.D001-1
- initial version
